import { PACKAGE_NAME } from "./package-name";
import { LinkName } from './contains';
/**
 * Inserts push notification
 *
 * @example
```ts
const { pushNotificationLinkId } = await insertPushNotification({
  deep,
  pushNotification,
})
```
 */
export async function insertPushNotification(param) {
    const { deep, pushNotification, containerLinkId = deep.linkId } = param;
    const pushNotificationTypeLinkId = await deep.id(PACKAGE_NAME, LinkName[LinkName.PushNotification]);
    const titleTypeLinkId = await deep.id(PACKAGE_NAME, LinkName[LinkName.PushNotificationTitle]);
    const bodyTypeLinkId = await deep.id(PACKAGE_NAME, LinkName[LinkName.PushNotificationBody]);
    const imageUrlTypeLinkId = await deep.id(PACKAGE_NAME, LinkName[LinkName.PushNotificationImageUrl]);
    const syncTextFileTypeLinkId = await deep.id('@deep-foundation/core', 'SyncTextFile');
    const containTypeLinkId = await deep.id('@deep-foundation/core', 'Contain');
    const { data: [{ id: pushNotificationLinkId }] } = await deep.insert({
        type_id: pushNotificationTypeLinkId,
        in: {
            data: [
                {
                    type_id: containTypeLinkId,
                    from_id: containerLinkId,
                },
            ],
        },
        out: {
            data: [
                {
                    type_id: titleTypeLinkId,
                    to: {
                        data: {
                            type_id: syncTextFileTypeLinkId,
                            in: {
                                data: [
                                    {
                                        type_id: containTypeLinkId,
                                        from_id: containerLinkId,
                                    },
                                ],
                            },
                            string: {
                                data: {
                                    value: pushNotification.title,
                                },
                            },
                        },
                    },
                    in: {
                        data: [
                            {
                                type_id: containTypeLinkId,
                                from_id: containerLinkId,
                            },
                        ],
                    },
                },
                {
                    type_id: bodyTypeLinkId,
                    to: {
                        data: {
                            type_id: syncTextFileTypeLinkId,
                            in: {
                                data: [
                                    {
                                        type_id: containTypeLinkId,
                                        from_id: containerLinkId,
                                    },
                                ],
                            },
                            string: {
                                data: {
                                    value: pushNotification.body,
                                },
                            },
                        },
                    },
                    in: {
                        data: [
                            {
                                type_id: containTypeLinkId,
                                from_id: containerLinkId,
                            },
                        ],
                    },
                },
                ...(pushNotification.image ? [{
                        type_id: imageUrlTypeLinkId,
                        to: {
                            data: {
                                type_id: syncTextFileTypeLinkId,
                                in: {
                                    data: [
                                        {
                                            type_id: containTypeLinkId,
                                            from_id: containerLinkId,
                                        },
                                    ],
                                },
                                string: {
                                    data: {
                                        value: pushNotification.body,
                                    },
                                },
                            },
                        },
                        in: {
                            data: [
                                {
                                    type_id: containTypeLinkId,
                                    from_id: containerLinkId,
                                },
                            ],
                        },
                    }] : [])
            ],
        },
    });
    return { pushNotificationLinkId };
}
