import { PACKAGE_NAME } from './package-name';
import { LinkName } from './contains';
/**
 * Inserts service account
 *
 * @example
```ts
const { serviceAccountLinkId } = await insertServiceAccount({
  deep,
  serviceAccount,
  shouldMakeActive,
})
```
 */
export async function insertServiceAccount(param) {
    const { deep, serviceAccount, shouldMakeActive = false, } = param;
    const containTypeLinkId = await deep.id('@deep-foundation/core', 'Contain');
    const serviceAccountTypeLinkId = await deep.id(PACKAGE_NAME, LinkName[LinkName.ServiceAccount]);
    const usesServiceAccountTypeLinkId = await deep.id(PACKAGE_NAME, LinkName[LinkName.UsesServiceAccount]);
    if (shouldMakeActive) {
        await deep.delete({
            up: {
                tree_id: { _eq: await deep.id('@deep-foundation/core', 'containTree') },
                parent: {
                    type_id: { _id: ['@deep-foundation/core', 'Contain'] },
                    to: { type_id: usesServiceAccountTypeLinkId },
                    from_id: deep.linkId,
                },
            },
        });
    }
    const { data: [{ id: serviceAccountLinkId }] } = await deep.insert({
        type_id: serviceAccountTypeLinkId,
        object: {
            data: {
                value: serviceAccount,
            },
        },
        in: {
            data: [
                {
                    type_id: containTypeLinkId,
                    from_id: deep.linkId,
                },
                ...(shouldMakeActive
                    ? [
                        {
                            type_id: usesServiceAccountTypeLinkId,
                            from_id: deep.linkId,
                            in: {
                                data: [
                                    {
                                        type_id: containTypeLinkId,
                                        from_id: deep.linkId,
                                    },
                                ],
                            },
                        },
                    ]
                    : []),
            ],
        },
    });
    return { serviceAccountLinkId };
}
